@@ -382,6 +382,11 @@ impl Screen {
     }
 
     fn exec_selected(&mut self) {
+        if self.is_test {
+            // tests generate many randomly named nodes, so we don't
+            // want to accidentally execute rm -rf /
+            return;
+        }
         if let Some(selected_id) = self.selected {
             let content_opt = self.with_node(selected_id, |n| n.content.clone());
             if content_opt.is_none() {
@@ -480,7 +485,7 @@ impl Screen {
             top: 2, // leave room for header
             left: 1, // 1-indexed screen
             bottom: std::u16::MAX, // make this "bottomless" since we can paginate
-            right: self.dims.0 - 1,
+            right: cmp::max(self.dims.0, 1) - 1,
             elem: None,
         };
 
@@ -495,8 +500,9 @@ impl Screen {
             // add some spacing around this tree to space out
             // placement a little bit
             let padded_dims = (dims.0 + 2, dims.1 + 2);
-            let (x, y) = real_estate.insert(padded_dims).unwrap();
-            self.with_node_mut(node_id, |n| n.rooted_coords = (x, y)).unwrap();
+            if let Some((x, y)) = real_estate.insert(padded_dims) {
+                self.with_node_mut(node_id, |n| n.rooted_coords = (x, y)).unwrap();
+            }
         }
     }
 
@@ -590,7 +596,7 @@ impl Screen {
     }
 
     fn screen_to_internal_xy(&self, coords: Coords) -> Coords {
-        (coords.0, coords.1 + self.view_y)
+        (coords.0, cmp::min(coords.1, std::u16::MAX - self.view_y) + self.view_y)
     }
 
     fn coords_are_visible(&self, (_, y): Coords) -> bool {
@@ -776,6 +782,10 @@ impl Screen {
             // that's wide enough, then create
             // an anchor there.
             let mut width = 0;
+            if self.dims.0 < 2 {
+                from_x = Some(1);
+                break;
+            }
             for x in 1..self.dims.0 {
                 if self.lookup((x, y_cursor)).is_none() {
                     width += 1;
@@ -1287,7 +1297,7 @@ impl Screen {
     }
 
     fn draw_scrollbar(&self) {
-        let bar_height = self.dims.1 - 1;
+        let bar_height = cmp::max(self.dims.1, 1) - 1;
         let normalized_lowest = cmp::max(self.lowest_drawn, 1) as f64;
         let fraction_viewable = self.dims.1 as f64 / normalized_lowest;
         let shade_start_fraction = self.view_y as f64 / normalized_lowest;
@@ -1531,7 +1541,7 @@ impl Screen {
                                   header_text,
                                   style::Reset);
             let text_len = header_text.chars().count();
-            for _ in 0..(self.dims.0 as usize - text_len) {
+            for _ in 0..(cmp::max(self.dims.0 as usize, text_len) - text_len) {
                 sep.push('█');
             }
             println!("{}", sep);
